@@ -2,8 +2,6 @@ use warnings;
 use strict;
 
 package XML::Compile::Schema::BuiltInFacets;
-use vars '$VERSION';
-$VERSION = '0.02';
 use base 'Exporter';
 
 our @EXPORT = qw/builtin_facet/;
@@ -15,6 +13,28 @@ use constant DBL_MAX_EXP => 307;
 use constant INT_MAX => int((sprintf"%u\n",-1)/2);
 use constant INT_MIN => -1 - INT_MAX;
 
+=chapter NAME
+
+XML::Compile::Schema::BuiltInFacets - handling of built-in facet checks
+
+=chapter SYNOPSIS
+
+ # Not for end-users
+ use XML::Compile::Schema::BuiltInFacets qw/%facets/;
+
+=chapter DESCRIPTION
+
+This package implements the facet checks.  Facets are used to
+express restrictions on variable content which need to be checked
+dynamically.
+
+The content is not for end-users, but called by the schema translator.
+
+=chapter FUNCTIONS
+
+=function builtin_facet PATH, ARGS, TYPE, [VALUE]
+
+=cut
 
 my %facets =
  ( whiteSpace      => \&_whiteSpace
