@@ -3,11 +3,29 @@ use warnings;
 use strict;
 
 package XML::Compile::Schema::NameSpaces;
-use vars '$VERSION';
-$VERSION = '0.02';
 
 use Carp;
 
+=chapter NAME
+
+XML::Compile::Schema::NameSpaces - Connect name-spaces from schemas
+
+=chapter SYNOPSIS
+
+ # Used internally by XML::Compile::Schema
+ my $nss = XML::Compile::Schema::NameSpaces->new;
+ $nss->add($schema);
+
+=chapter DESCRIPTION
+
+This module keeps overview on a set of schema's.
+
+=chapter METHODS
+
+=section Constructors
+
+=method new OPTIONS
+=cut
 
 sub new($@)
 {   my $class = shift;
@@ -20,9 +38,18 @@ sub init($)
     $self;
 }
 
+=section Accessors
+
+=method namespaces
+Returns the list of names defined until now.
+=cut
 
 sub namespaces() { keys %{shift->{tns}} }
 
+=method namespace URI
+Returns a list of M<XML::Compile::Schema::Instance> objects which have
+the URI as target namespace.
+=cut
 
 sub namespace($)
 {   my $self = shift;
@@ -30,6 +57,10 @@ sub namespace($)
     $nss ? @$nss : ();
 }
 
+=method add SCHEMA
+Adds the M<XML::Compile::Schema::Instance> object to the internal
+knowledge of this object.
+=cut
 
 sub add($)
 {   my ($self, $schema) = @_;
@@ -38,6 +69,9 @@ sub add($)
     $schema;
 }
 
+=method schemas URI
+We need the name-space; when it is lacking then import must help.
+=cut
 
 sub schemas($)
 {   my ($self, $ns) = @_;
@@ -48,6 +82,10 @@ sub schemas($)
     croak "ERROR: namespace $ns not known";
 }
 
+=method findElement ADDRESS|(URI,NAME)
+Lookup the definition for the specified element, which is constructed as
+C< {uri}name > or as seperate URI and NAME.
+=cut
 
 sub findElement($;$)
 {   my ($self, $ns, $name) = @_;
@@ -64,6 +102,10 @@ sub findElement($;$)
     undef;
 }
 
+=method findType ADDRESS|(URI,NAME)
+Lookup the definition for the specified type, which is constructed as
+C< {uri}name > or as seperate URI and NAME.
+=cut
 
 sub findType($;$)
 {   my ($self, $ns, $name) = @_;
@@ -80,6 +122,10 @@ sub findType($;$)
     undef;
 }
 
+=method findID ADDRESS|(URI,ID)
+Lookup the definition for the specified id, which is constructed as
+C< uri#id > or as seperate URI and ID.
+=cut
 
 sub findID($;$)
 {   my ($self, $ns, $name) = @_;
